ATel #2: GB971227

Outside GCN IAUCs Other ATel on Twitter and Facebook ATELstream ATel Community Site | Post | Search | Policies Credential | Feeds | Email 4 May 2020; 18:39 UT | This space for free for your conference.

[ Previous | Next | ADS ] # GB971227 ATel #2; R. Rutledge on 28 Dec 1997; 04:43 UT Distributed as an Instant Email Notice Gamma-Ray Bursts Credential Certification: rutledge@rosat.mpe-garching.mpg.de Subjects: Gamma Ray, Gamma-Ray Burst Tweet The following message was emailed to me this evening by Walter Lewin at MIT. - -------------------------------------------------------------- A GRB (GB971227, Bacodine trigger 6546) has been detected by BeppoSAX GRBM and WFC at 8:23:06 UT. Coordinates from WFC are: RA(2000)=194.373 Dec(2000)=59.27 The event was detected when the satellite was in a not optimal attitude configuration, with an estimated error radius of about 10'. Luigi Piro on behalf of the BeppoSAX team #----------------------------------#------------------------------------------# Luigi Piro | E-mail: Istituto Astrofisica Spaziale | piro@alpha1.ias.rm.cnr.it C.N.R. | SAX program: saxsci@alpha1.ias.rm.cnr.it Via Fosso del Cavaliere | phone: -39-6-4993-4007 I-00133 Roma | phone BeppoSAX center: -39-6-4079-6393 Italy | fax(CNR) : -39-6-20660188 #__________________________________#___________________________________________# |